Page 18 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 18

Home

    in the condemnation of Mystery Babylon. Many of these
    verses are found in the 51st chapter of Jeremiah.

    As in the case of Ancient Babylon, Mystery Babylon's
    fall comes suddenly and at a time when its leaders are

    How much she hath glorified herself, and lived
    deliriously, so much torment and sorrow give her: for
    she saith in her heart, I sit a queen, and am no widow,

    ,ao4n

    Therefore shall her plagues come in one day, death,
    and mourning, and famine;. . .

    n tat 190.0

    While Ancient Babylon and Mystery Babylon constitute
    an amazing parallel, there is another far more important
    parallel. This is the parallel of Mystery Babylon and a
    world structure that has been built in this century and has

    as its goal the total subjugation of the human race under a
    New World Order.

    this present world structure as Modern Day Babylon. In
    order to illustrate its parallel to Mystery Babylon, we
    will examine some of the events occurring on the secret

    13

    Mystery Babylon

    confident of their security:

    and shall see no sorrow.

    Revelation 18:7

    Revelation 18:8

    For purpose of comparison, we have chosen to label

    side of history from ancient times to the present.